==> bip32_ed25519-0.4.0.tar.gz: example/scan/accounts.dart <==
import 'dart:async';

import 'package:pinenacl/digests.dart';

import 'package:bip32_ed25519/api.dart';
import 'package:bip32_ed25519/bip32_ed25519.dart';

import 'coin.dart';
import 'scanner.dart';

/// https://github.com/input-output-hk/cardano-addresses
class Address {
  Address(this.account, this.index);

  final Account account;
  final int index;

  String get path =>
      '${account.path}/${Bip32KeyTree.indexToPathNotation(index)}';
  Bip32Ed25519 get chain => account.chain;

  // ignore: non_constant_identifier_names
  String get toBaseAddress {
    final pk = chain.pathToKey(path).publicKey;
    final a = Hash.blake2b(pk.asTypedList, digestSize: 28);

    const coder = Bech32Coder(hrp: 'addr_test');
    final addr = ByteList([0x60] + a).encode(coder);

    print('Address: $addr');
    return addr;
  }
}

class Account {
  Account(this.coin, this.index, this.change);

  final Coin coin;
  final int index;
  final int change;

  String get path =>
      '${coin.path}/${Bip32KeyTree.indexToPathNotation(index)}/$change';
  Bip32Ed25519 get chain => coin.chain;
  Future<bool> get isUsed async {
    return (await nextUnusedAddress()).index != 0;
  }

  Future<Address> nextUnusedAddress() async {
    var used = await usedAddresses();

    if (used.isEmpty) {
      return Address(this, 0);
    }

    return Address(this, used.last.index + 1);
  }

  Future<List<Address>> usedAddresses() async {
    var usedAddresses = <Address>[];

    var addressIndex = 0;
    var nextAddress = Address(this, addressIndex);

    while (await scanners[0].present(nextAddress.toBaseAddress)) {
      usedAddresses.add(nextAddress);
      addressIndex++;
      nextAddress = Address(this, addressIndex);
    }

    return usedAddresses;
  }

  Account next() {
    return Account(coin, index + 1, 0);
  }
}

==> bip32_ed25519-0.5.0.tar.gz: example/scan/accounts.dart <==
import 'dart:async';

import 'package:bip32_ed25519/api.dart';
import 'package:bip32_ed25519/bip32_ed25519.dart';

import 'coin.dart';
import 'scanner.dart';

/// https://github.com/input-output-hk/cardano-addresses
class Address {
  Address(this.account, this.index);

  final Account account;
  final int index;

  String get path =>
      '${account.path}/${Bip32KeyTree.indexToPathNotation(index)}';
  Bip32Ed25519 get chain => account.chain;

  // ignore: non_constant_identifier_names
  String get toBaseAddress {
    final pk = chain.pathToKey(path).publicKey;
    final a = Hash.blake2b(pk.asTypedList, digestSize: 28);

    const coder = Bech32Encoder(hrp: 'addr_test');
    final addr = ByteList([0x60] + a).encode(coder);

    print('Address: $addr');
    return addr;
  }
}

class Account {
  Account(this.coin, this.index, this.change);

  final Coin coin;
  final int index;
  final int change;

  String get path =>
      '${coin.path}/${Bip32KeyTree.indexToPathNotation(index)}/$change';
  Bip32Ed25519 get chain => coin.chain;
  Future<bool> get isUsed async {
    return (await nextUnusedAddress()).index != 0;
  }

  Future<Address> nextUnusedAddress() async {
    var used = await usedAddresses();

    if (used.isEmpty) {
      return Address(this, 0);
    }

    return Address(this, used.last.index + 1);
  }

  Future<List<Address>> usedAddresses() async {
    var usedAddresses = <Address>[];

    var addressIndex = 0;
    var nextAddress = Address(this, addressIndex);

    while (await scanners[0].present(nextAddress.toBaseAddress)) {
      usedAddresses.add(nextAddress);
      addressIndex++;
      nextAddress = Address(this, addressIndex);
    }

    return usedAddresses;
  }

  Account next() {
    return Account(coin, index + 1, 0);
  }
}
